# Screen Recorder

This library allows you to record your screen and save it as a video, mainly made for small screen recordings and not something serious.

# Installation

You can install the package with pip:

```bash
pip screenreclib
